
function varargout = vargtest(inArgA, inArg2, varargin) 
% vargtest - Variable number of arguments example (v. 1.0).
%
% This function accepts 0 to n inputs, returns 0 to n outputs. It assumes 
% the first input and output arguments are strings and the rest are 
% numeric.
%
% This is a substantially modified version of a sample function in Matlab
% help.
%
% Modifed by Dr. C. S. Tritt
% Last revised 11/30/11

fprintf('In vargtest...\n');

% Display number of input and output arguments.
fprintf('Number of input arguments = %d\n', nargin);
fprintf('Number of output arguments = %d\n', nargout);

% Calculate number of optional and standard (individual) input arguments. 
optargin = size(varargin,2);
stdargin = nargin - optargin;

% Display information and content of varargin. Note that the optional input
% arguments are ordinary scalar or matrices, but appear in this function as
% elements in a cell array.

% Display individual (regular) input argument values.
fprintf('Inputs from individual arguments(%d):\n', ...
        stdargin)
if stdargin >= 1
    fprintf('inArgA is %s\n', inArgA)
end
if stdargin == 2
    fprintf('inArg2 is %d\n', inArg2)
end

% Display variable input argument information and values.
fprintf('Class of varargin: %s\n', class(varargin));
fprintf('Number of items in varargin(%d):\n', optargin)
fprintf('Disp of varargin:\n');
disp(varargin);

% Generate the correct number of returned values.
% Note that returned values are put in a cell array but appear in the
% calling program as normal matrices and scalars.

% Preallocate varargout.
varargout = cell(nargout);
% First returned argument assumed to be a string.
if nargout >= 1
   varargout{1} = 'abc123';
end
% Other returned arguments assumed to be numeric.
for j = 2:nargout
   varargout{j} = j;
end
fprintf('Returning from vargtest...\n\n');